@@ -23,8 +23,8 @@
 #include <mailtransport_export.h>
 #include <transporttype.h>
 
-#include <QtCore/QList>
-#include <QtCore/QObject>
+#include <QList>
+#include <QObject>
 
 class KJob;
 
@@ -185,8 +185,9 @@ public:
       @return True if the user clicked Ok, false if the user cancelled.
       @since 4.4
     */
-    bool configureTransport(Transport *transport, QWidget *parent);
+    bool configureTransport(const QString &identifier, Transport *transport, QWidget *parent);
 
+    void initializeTransport(const QString &identifier, Transport *transport);
 public Q_SLOTS:
     /**
       Returns true if there are no mail transports at all.
@@ -283,6 +284,7 @@ private:
 
     // These are used by our friend, Transport
     void emitChangesCommitted();
+    void updatePluginList();
 
 private:
     TransportManagerPrivate *const d;
